@@ -1,23 +1,23 @@
 use std::fmt;
 
+use crate::DebugLisp;
+
 #[derive(Clone, Copy, Default, PartialEq)]
 pub struct Span {
 	pub start: Position,
 	pub end: Position,
 }
 
-impl fmt::Debug for Span {
-	fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-		write!(f, "{:?}...{:?}", self.start, self.end)
-	}
-}
-
 #[derive(Clone, Copy, Default, PartialEq)]
 pub struct Position {
 	pub line: usize,
 	pub character: usize,
 }
 
+pub trait Spanned {
+	fn span(&self) -> Span;
+}
+
 #[macro_export]
 macro_rules! span {
 	($start_line:literal:$start_char:literal...$end_line:literal:$end_char:literal) => {
@@ -38,6 +38,25 @@ impl Span {
 			},
 		}
 	}
+
+	pub fn through(self, other: Span) -> Span {
+		Span {
+			start: self.start,
+			end: other.end,
+		}
+	}
+}
+
+impl fmt::Debug for Span {
+	fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+		write!(f, "{:?}...{:?}", self.start, self.end)
+	}
+}
+
+impl DebugLisp for Span {
+	fn fmt(&self, f: &mut fmt::Formatter<'_>, _: usize) -> fmt::Result {
+		fmt::Debug::fmt(self, f)
+	}
 }
 
 impl fmt::Debug for Position {
